# Py Inspector

## Versão:

[![PyPi version](https://pypip.in/v/py-inspector/badge.png)](https://pypi.python.org/pypi/py-inspector)
[![PyPi downloads](https://pypip.in/d/py-inspector/badge.png)](https://pypi.python.org/pypi/py-inspector)


## Build Status

### Master

[![Build Status](https://travis-ci.org/Maethorin/py-inspector.svg?branch=master)](https://travis-ci.org/Maethorin/py-inspector)
[![Coverage Status](https://coveralls.io/repos/Maethorin/py-inspector/badge.svg?branch=master)](https://coveralls.io/r/Maethorin/py-inspector?branch=master)

## Descrição

Possibilita a criação de testes para PEP8 e PyLint que serão executados com nose
